@@ -96,7 +96,9 @@ class FMP_CONNECTION(object):
 
                 historical_df.index = pd.to_datetime(historical_df.index, infer_datetime_format=True)
 
-                historical_df['change'] = historical_df['close'].pct_change()            
+                historical_df['change'] = historical_df['close'].pct_change()   
+
+                historical_df['realOpen'] = historical_df['close'].shift(1)         
             
 
             
@@ -113,6 +115,8 @@ class FMP_CONNECTION(object):
 
             historical_df['change'] = historical_df['close'].pct_change()
 
+            historical_df['realOpen'] = historical_df['close'].shift(1)
+
             return historical_df
 
         url = f'https://financialmodelingprep.com/api/v3/historical-price-full/{ticker}?apikey={self._api_key}'
@@ -133,6 +137,9 @@ class FMP_CONNECTION(object):
 
             df['change'] = df['close'].pct_change()
 
+            df['realOpen'] = df['close'].shift(1)
+
+
             return df
 
         elif interval == '1m':
@@ -143,6 +150,8 @@ class FMP_CONNECTION(object):
 
             df['change'] = df['close'].pct_change()
 
+            df['realOpen'] = df['close'].shift(1)
+
             return df
 
         elif interval == '1q':
@@ -153,6 +162,8 @@ class FMP_CONNECTION(object):
 
             df['change'] = df['close'].pct_change()
 
+            df['realOpen'] = df['close'].shift(1)
+
             return df
 
         elif interval == '1y':
@@ -163,6 +174,8 @@ class FMP_CONNECTION(object):
 
             df['change'] = df['close'].pct_change()
 
+            df['realOpen'] = df['close'].shift(1)
+
             return df
     
         else:
